@@ -2,7 +2,7 @@
 /*
  * libopenraw - cr2file.cpp
  *
- * Copyright (C) 2006-2017 Hubert Figuière
+ * Copyright (C) 2006-2018 Hubert Figuière
  * Copyright (C) 2008 Novell, Inc.
  *
  * This library is free software: you can redistribute it and/or
@@ -143,10 +143,20 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 7457,-671,-937,-4849,12495,2643,-1213,2354,5492 } },
+    // From DNG Converter 10.3
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_800D),
+      0,
+      0,
+      { 6970, -512, -968, -4425, 12161, 2553, -739, 1982, 5601 } },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_100D),
       0,
       0x350f,
       { 6602, -841, -939, -4472, 12458, 2247, -975, 2039, 6148 } },
+    // From DNG Converter 10.3
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_200D),
+      0,
+      0x350f,
+      { 7377, -742, -998, -4235, 11981, 2549, -673, 1918, 5538 } },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_1000D),
       0,
       0xe43,
@@ -184,10 +194,23 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0x3bb0,
       {  6014, -220, -795, -4109, 12014, 2361, -561, 1824, 5787 } },
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_5DS),
+      0,
+      0xe6c,
+      { 6250, -711, -808, -5153, 12794, 2636, -1249, 2198, 5610 } },
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_5DS_R),
+      0,
+      0xe6c,
+      { 6250, -711, -808, -5153, 12794, 2636, -1249, 2198, 5610 } },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_6D),
       0,
       0x3c82,
       { 7034, -804, -1014, -4420, 12564, 2058, -851, 1994, 5758 } },
+    // From DNG Converter 10.3
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_6DMKII),
+      0,
+      0,
+      { 6875, -970, -932, -4691, 12459, 2501, -874, 1953, 5809 } },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_7D),
       0,
       0x3510,
@@ -208,6 +231,11 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0x350f,
       { 6362, -823, -847, -4426, 12109, 2616, -743, 1857, 5635 } },
+    // Fron DNG Converter 10.3
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_77D),
+      0,
+      0,
+      { 7377, -742, -998, -4235, 11981, 2549, -673, 1918, 5538 } },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M),
       0,
       0,
@@ -216,10 +244,20 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 6362, -823, -847, -4426, 12109, 2616, -743, 1857, 5635 } },
+    // From DNG Converter 10.3
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M5),
+      0,
+      0,
+      { 8532, -701, -1167, -4095, 11879, 2508, -797, 2424, 7010 } },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M10),
       0,
       0,
       { 6400, -480, -888, -5294, 13416, 2047, -1296, 2203, 6137 } },
+    // From DNG Converter 10.3
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M100),
+      0,
+      0,
+      { 8532, -701, -1167, -4095, 11879, 2508, -797, 2424, 7010 } },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G9),
       0,
       0,
@@ -250,6 +288,11 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 7378, -1255, -1043, -4088, 12251, 2048, -876, 1946, 5805 } },
+    // From DNG Converter 10.3
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G1XMKIII),
+      0,
+      0,
+      { 8532, -701, -1167, -4095, 11879, 2508, -797, 2424, 7010 } },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G3X),
       0,
       0,
@@ -258,14 +301,24 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 9602, -3823, -937, -2984, 11495, 1675, -407, 1415, 5049 } },
+    // From DNG Converter 10.3
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G7X),
       0,
       0,
       { 9602, -3823, -937, -2984, 11495, 1675, -407, 1415, 5049 } },
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G7XMKII),
+      0,
+      0,
+      { 9602, -3823, -937, -2984, 11495, 1675, -407, 1415, 5049 } },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G9X),
       0,
       0,
       { 9602, -3823, -937, -2984, 11495, 1675, -407, 1415, 5049 } },
+    // From DNG Converter 10.3
+    { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G9XMKII),
+      0,
+      0,
+      { 10056, -4131, -944, -2576, 11143, 1625, -238, 1294, 5179} },
     { OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_S90),
       0,
       0,
@@ -348,18 +401,23 @@ const IfdFile::camera_ids_t Cr2File::s_def[] = {
     { "Canon EOS REBEL T3", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_T3) },
     { "Canon EOS 100D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_100D) },
     { "Canon EOS REBEL SL1", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_SL1) },
+    { "Canon EOS 200D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_200D) },
+    { "Canon EOS Rebel SL2", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_REBEL_SL2) },
     { "Canon EOS 5D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_5D) },
     { "Canon EOS 5D Mark II", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_5DMKII) },
     { "Canon EOS 5D Mark III", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_5DMKIII) },
     { "Canon EOS 5D Mark IV", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_5DMKIV) },
+    { "Canon EOS 5DS", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_5DS) },
     { "Canon EOS 5DS R", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_5DS_R) },
     { "Canon EOS 6D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_6D) },
+    { "Canon EOS 6D Mark II", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_6DMKII) },
     { "Canon EOS 7D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_7D) },
     { "Canon EOS 7D Mark II", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_7DMKII) },
     { "Canon EOS 77D", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_77D) },
     { "Canon EOS Kiss X3", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_KISS_X3) },
     { "Canon EOS M", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M) },
     { "Canon EOS M10", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M10) },
+    { "Canon EOS M100", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M100) },
     { "Canon EOS M3", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M3) },
     { "Canon EOS M5", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M5) },
     { "Canon EOS M6", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_EOS_M6) },
@@ -372,6 +430,8 @@ const IfdFile::camera_ids_t Cr2File::s_def[] = {
     { "Canon PowerShot G1 X", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G1X) },
     { "Canon PowerShot G1 X Mark II",
       OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G1XMKII) },
+    { "Canon PowerShot G1 X Mark III",
+      OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G1XMKIII) },
     { "Canon PowerShot G3 X", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G3X) },
     { "Canon PowerShot G5 X", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G5X) },
     { "Canon PowerShot G7 X", OR_MAKE_CANON_TYPEID(OR_TYPEID_CANON_G7X) },
@@ -427,22 +487,22 @@ IfdDir::Ref Cr2File::_locateMainIfd()
         LOGDBG1("offset not found\n");
         return OR_ERROR_NOT_FOUND;
     }
-    uint32_t offset = result.unwrap();
+    uint32_t offset = result.value();
 
     result = _cfaIfd->getValue<uint32_t>(IFD::EXIF_TAG_STRIP_BYTE_COUNTS);
     if (result.empty()) {
         LOGDBG1("byte len not found\n");
         return OR_ERROR_NOT_FOUND;
     }
-    uint32_t byte_length = result.unwrap();
+    uint32_t byte_length = result.value();
 
     // get the "slicing", tag 0xc640 (3 SHORT)
     std::vector<uint16_t> slices;
     IfdEntry::Ref e = _cfaIfd->getEntry(IFD::CR2_TAG_SLICE);
     if (e) {
         auto result2 = e->getArray<uint16_t>();
-        if (result2.ok()) {
-            slices = result2.unwrap();
+        if (result2) {
+            slices = result2.value();
             LOGDBG1("Found slice entry count %ld\n", slices.size());
         }
     }
@@ -458,14 +518,14 @@ IfdDir::Ref Cr2File::_locateMainIfd()
         LOGDBG1("X not found\n");
         return OR_ERROR_NOT_FOUND;
     }
-    uint16_t x = result2.unwrap();
+    uint16_t x = result2.value();
 
     result2 = _exifIfd->getValue<uint16_t>(IFD::EXIF_TAG_PIXEL_Y_DIMENSION);
     if (result2.empty()) {
         LOGDBG1("Y not found\n");
         return OR_ERROR_NOT_FOUND;
     }
-    uint16_t y = result2.unwrap();
+    uint16_t y = result2.value();
 
     void *p = data.allocData(byte_length);
     size_t real_size = m_container->fetchData(p, offset, byte_length);
@@ -505,8 +565,8 @@ IfdDir::Ref Cr2File::_locateMainIfd()
     e = _makerNoteIfd->getEntry(IFD::MNOTE_CANON_SENSORINFO);
     if (e) {
         auto result3 = e->getArray<uint16_t>();
-        if (result3.ok()) {
-            std::vector<uint16_t> sensorInfo = result3.unwrap();
+        if (result3) {
+            std::vector<uint16_t> sensorInfo = result3.value();
             if (sensorInfo.size() > 8) {
                 uint32_t w = sensorInfo[7] - sensorInfo[5];
                 uint32_t h = sensorInfo[8] - sensorInfo[6];
