@@ -111,6 +111,8 @@ const IfdFile::camera_ids_t DngFile::s_def[] = {
                                                OR_TYPEID_LEICA_T_TYP701) },
     { "LEICA Q (Typ 116)", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_LEICA,
                                                OR_TYPEID_LEICA_Q_TYP116) },
+    { "LEICA CL", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_LEICA,
+                                               OR_TYPEID_LEICA_CL) },
     { "GR DIGITAL 2   ", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_RICOH,
                                              OR_TYPEID_RICOH_GR2) },
     { "GR                                                             ",
@@ -169,7 +171,7 @@ DngFile::~DngFile()
     }
 
     auto result = _cfaIfd->getValue<uint16_t>(IFD::EXIF_TAG_COMPRESSION);
-    if (result.ok() && (result.unwrap() == IFD::COMPRESS_LJPEG)) {
+    if (result && (result.value() == IFD::COMPRESS_LJPEG)) {
         // if the option is not set, decompress
         if ((options & OR_OPTIONS_DONT_DECOMPRESS) == 0) {
             IO::Stream::Ptr s(
@@ -221,7 +223,7 @@ void DngFile::_identifyId()
 
         auto uniqueCameraModel =
             _mainIfd->getValue<std::string>(IFD::DNG_TAG_UNIQUE_CAMERA_MODEL);
-        if (uniqueCameraModel.ok()) {
+        if (uniqueCameraModel) {
             // set a generic DNG type if we found a
             // unique camera model
             _setTypeId(
