@@ -114,15 +114,16 @@ size_t IfdFileContainer::getDirectoryDataSize()
     LOGDBG1("getDirectoryDataSize()\n");
     off_t dir_offset = m_current_dir->offset();
     // FIXME check error
-    LOGDBG1("offset = %ld m_numTags = %d\n", dir_offset, m_current_dir->numTags());
+    LOGDBG1("offset = %lld m_numTags = %d\n", (long long int)dir_offset,
+            m_current_dir->numTags());
     off_t begin = dir_offset + 2 + (m_current_dir->numTags() * 12);
 
-    LOGDBG1("begin = %ld\n", begin);
+    LOGDBG1("begin = %lld\n", (long long int)begin);
 
     m_file->seek(begin, SEEK_SET);
     begin += 2;
 
-    int32_t nextIFD = readInt32(m_file).unwrap_or(0);
+    int32_t nextIFD = readInt32(m_file).value_or(0);
     LOGDBG1("nextIFD = %d\n", nextIFD);
     if (nextIFD == 0) {
         // FIXME not good
@@ -153,7 +154,7 @@ bool IfdFileContainer::_locateDirs(void)
         }
     }
     m_file->seek(m_offset + 4, SEEK_SET);
-    int32_t dir_offset = readInt32(m_file).unwrap_or(0);
+    int32_t dir_offset = readInt32(m_file).value_or(0);
     m_dirs.clear();
     do {
         if (dir_offset != 0) {
