@@ -2,7 +2,7 @@
 /*
  * libopenraw - neffile.cpp
  *
- * Copyright (C) 2006-2017 Hubert Figuiere
+ * Copyright (C) 2006-2017 Hubert Figuière
  * Copyright (C) 2008 Novell, Inc.
  *
  * This library is free software: you can redistribute it and/or
@@ -171,7 +171,11 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 8821, -2938, -785, -4178, 12142, 2287, -824, 1651, 6860 } },
-
+    // From DNG Converter 10.3
+    { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D5600),
+      0,
+      0,
+      { 8821, -2938, -785, -4178, 12142, 2287, -824, 1651, 6860 } },
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D60),
       0,
       0,
@@ -255,7 +259,19 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 7842,-2320,-992,-8154,15718,2599,-1098,1342,7560 } },
-
+    // From DNG Converter 10.3
+    { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_B700),
+      200,
+      0,
+      { 14387, -6014, -1299, -1357, 9975, 1616, 467, 1047, 4744 } },
+    { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P330),
+      200,
+      0,
+      { 10321, -3920, -931, -2750, 11146, 1824, -442, 1545, 5539 } },
+    { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P340),
+      200,
+      0,
+      { 10321, -3920, -931, -2750, 11146, 1824, -442, 1545, 5539 } },
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P6000),
       0,
       0,
@@ -379,6 +395,9 @@ const IfdFile::camera_ids_t NefFile::s_def[] = {
     { "E5400", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_E5400) },
     { "E5700", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_E5700) },
     { "E8400", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_E8400) },
+    { "COOLPIX B700", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_B700) },
+    { "COOLPIX P330", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P330) },
+    { "COOLPIX P340", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P340) },
     { "COOLPIX P6000", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P6000) },
     { "COOLPIX P7000", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7000) },
     { "COOLPIX P7100", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7100) },
@@ -426,19 +445,57 @@ bool NefFile::isCompressed(RawContainer & container, uint32_t offset)
     }
     for(i = 15; i < 256; i+= 16) {
         if(buf[i]) {
-            Trace(DEBUG1) << "isCompressed: true\n";
+            LOGDBG1("isCompressed: true\n");
             return true;
         }
     }
-    Trace(DEBUG1) << "isCompressed: false\n";
+    LOGDBG1("isCompressed: false\n");
     return false;
 }
 
+bool NefFile::isNrw()
+{
+    MakerNoteDir::Ref _makerNoteIfd = makerNoteIfd();
+    if(!_makerNoteIfd) {
+        LOGERR("makernote not found\n");
+        return false;
+    }
+    auto value = _makerNoteIfd->getValue<std::string>(IFD::MNOTE_NIKON_QUALITY);
+    if (value && value.value() == "NRW") {
+        LOGDBG1("NRW found");
+        return true;
+    }
+    return false;
+}
+
+::or_error
+NefFile::_unpackData(uint16_t bpc, uint32_t compression, RawData & data,
+                     uint32_t x, uint32_t y, uint32_t offset, uint32_t byte_length)
+{
+    if (typeId() == OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D100)) {
+        x += 6;
+    }
+    return TiffEpFile::_unpackData(bpc, compression, data, x, y, offset, byte_length);
+}
+
+
+uint32_t NefFile::_translateCompressionType(IFD::TiffCompress tiffCompression)
+{
+    if (tiffCompression == IFD::COMPRESS_NIKON_QUANTIZED) {
+        // must check whether it is really compressed
+        // only for D100
+        if (typeId() == OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D100)) {
+            return IFD::COMPRESS_NIKON_PACK;
+        }
+    }
+    return TiffEpFile::_translateCompressionType(tiffCompression);
+}
+
 ::or_error NefFile::_decompressNikonQuantized(RawData & data)
 {
     NEFCompressionInfo c;
     if (!_getCompressionCurve(data, c)) {
-        Trace(ERROR) << "compression curve not found\n";
+        LOGERR("compression curve not found\n");
         return OR_ERROR_NOT_FOUND;
     }
     const uint32_t rows = data.height();
@@ -478,7 +535,10 @@ bool NefFile::isCompressed(RawContainer & container, uint32_t offset)
                                         uint32_t options)
 {
     uint32_t compression = data.compression();
-    if((options & OR_OPTIONS_DONT_DECOMPRESS) ||
+    if (isNrw()) {
+        LOGDBG1("NRW file found, currently not supported.");
+        return OR_ERROR_INVALID_FORMAT;
+    } else if((options & OR_OPTIONS_DONT_DECOMPRESS) ||
        compression == IFD::COMPRESS_NONE) {
         return OR_ERROR_NONE;
     } else if(compression == IFD::COMPRESS_NIKON_QUANTIZED) {
@@ -493,12 +553,12 @@ NefFile::_getCompressionCurve(RawData & data,  NefFile::NEFCompressionInfo& c)
 {
     MakerNoteDir::Ref _makerNoteIfd = makerNoteIfd();
     if(!_makerNoteIfd) {
-        Trace(ERROR) << "makernote not found\n";
+        LOGERR("makernote not found\n");
         return false;
     }
     IfdEntry::Ref curveEntry = _makerNoteIfd->getEntry(IFD::MNOTE_NIKON_NEFDECODETABLE2);
     if(!curveEntry) {
-        Trace(ERROR) << "decode table2 tag not found\n";
+        LOGERR("decode table2 tag not found\n");
         return false;
     }
 
@@ -509,16 +569,18 @@ NefFile::_getCompressionCurve(RawData & data,  NefFile::NEFCompressionInfo& c)
 
     uint16_t bpc = data.bpc();
     uint8_t header0, header1;
-    bool read = m_container->readUInt8(file, header0);
-    if(!read) {
-        Trace(ERROR) << "Header not found\n";
+    auto result = m_container->readUInt8(file);
+    if(result.empty()) {
+        LOGERR("Header not found\n");
         return false;
     }
-    read = m_container->readUInt8(file, header1);
-    if(!read) {
-        Trace(ERROR) << "Header not found\n";
+    header0 = result.value();
+    result = m_container->readUInt8(file);
+    if(result.empty()) {
+        LOGERR("Header not found\n");
         return false;
     }
+    header1 = result.value();
 
     if (header0 == 0x49) {
         // some interesting stuff at 2110
@@ -527,14 +589,14 @@ NefFile::_getCompressionCurve(RawData & data,  NefFile::NEFCompressionInfo& c)
         m_container->skip(2110);
     }
 
-    int16_t aux;
     for (int i = 0; i < 2; ++i) {
         for (int j = 0; j < 2; ++j) {
-            read = m_container->readInt16(file, aux);
-            if(!read) {
+            auto result16 = m_container->readInt16(file);
+            if(result16.empty()) {
+                LOGERR("Failed to read vpred (%d,%d)\n", i, j);
                 return false;
             }
-            c.vpred[i][j] = aux;
+            c.vpred[i][j] = result16.value();
         }
     }
 
@@ -573,8 +635,7 @@ NefFile::_getCompressionCurve(RawData & data,  NefFile::NEFCompressionInfo& c)
 
     // number of elements in the curve
     size_t nelems;
-    read = m_container->readInt16(file, aux);
-    nelems = aux;
+    nelems = m_container->readInt16(file).value_or(0);
     LOGDBG1("Num elems %ld\n", nelems);
 
     uint32_t ceiling = 1 << bpc & 0x7fff;
@@ -586,12 +647,12 @@ NefFile::_getCompressionCurve(RawData & data,  NefFile::NEFCompressionInfo& c)
 
     if (header0 == 0x44 && header1 == 0x20 && step > 0) {
         for (size_t i = 0; i < nelems; ++i) {
-            read = m_container->readInt16(file, aux);
-            if (!read) {
+            auto result16 = m_container->readInt16(file);
+            if (result16.empty()) {
                 LOGERR("NEF: short read\n");
                 return false;
             }
-            c.curve[i * step] = aux;
+            c.curve[i * step] = result16.value();
         }
         for (size_t i = 0; i < ceiling; ++i) {
             c.curve[i] = (c.curve[i - i % step] * (step - i % step) +
