@@ -89,6 +89,18 @@ static const BuiltinColourMatrix s_matrices[] = {
     15,
     0,
     { 7564, -2263, -606, -3148, 11239, 2177, -540, 1435, 4853 } },
+  { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX80),
+    15,
+    0,
+    { 7771, -3020, -629, -4029, 1195, 2345, -821, 1977, 6119 } },
+  { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX800),
+    15,
+    0,
+    { 7610, -2780, -576, -4614, 12195, 2733, -1375, 2393, 6490 } },
+  { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX9),
+    15,
+    0,
+    { 7564, -2263, -606, -3148, 11239, 2177, -540, 1435, 4853 } },
   { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ8),
     0,
     0xf7f,
@@ -105,6 +117,10 @@ static const BuiltinColourMatrix s_matrices[] = {
     143,
     0xfff,
     { 8112,-2563,-740,-3730,11784,2197,-941,2075,4933 } },
+  { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ2500),
+    143,
+    0xfff,
+    { 7386, -2443, -743, -3437, 11864, 1757, -608, 1660, 4766 } },
   { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ30),
     0,
     0xf94,
@@ -141,6 +157,14 @@ static const BuiltinColourMatrix s_matrices[] = {
     0,
     0,
     { 10113,-3400,-1114,-4765,12683,2317,-377,1437,6710 } },
+  { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G80),
+    15,
+    0,
+    { 7610, -2780, -576, -4614, 12195, 2733, -1375, 2393, 6490 } },
+  { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G9),
+    0,
+    0,
+    { 7685, -2375, -634, -3687, 11700, 2249, -748, 1546, 5111 } },
   { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GH1),
     15,
     0xf92,
@@ -201,6 +225,14 @@ static const BuiltinColourMatrix s_matrices[] = {
     15,
     0,
     {  7790, -2736, -755, -3452, 11870, 1769, -628, 1647, 4898 } },
+  { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ110),
+    15,
+    0,
+    { 7790, -2736, -755, -3452, 11870, 1769, -628, 1647, 4898 } },
+  { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ202),
+    15,
+    0,
+    {  7790, -2736, -755, -3452, 11870, 1769, -628, 1647, 4898 } },
 
   { OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DIGILUX2),
     0,
@@ -210,10 +242,18 @@ static const BuiltinColourMatrix s_matrices[] = {
     0,
     0,
     { 8048,-2810,-623,-6450,13519,3272,-1700,2146,7049 } },
+  { OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_TYP109),
+    0,
+    0,
+    { 8844, -3538, -768, -3709, 11762, 2200, -698, 1792, 5220 } },
   { OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_VLUX_1),
     0,
     0,
     { 7906,-2709,-594,-6231,13351,3220,-1922,2631,6537 } },
+  { OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_VLUX_4),
+    0,
+    0,
+    { 8112, -2563, -740, -3730, 11784, 2197, -941, 2075, 4933 } },
 
   { 0, 0, 0, { 0, 0, 0, 0, 0, 0, 0, 0, 0 } }
 };
@@ -230,7 +270,9 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
 	{ "DMC-GX7", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX7) },
 	{ "DMC-GX8", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX8) },
 	{ "DMC-GX80", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX80) },
+	{ "DC-GX800", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX800) },
 	{ "DC-GX850", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX850) },
+	{ "DC-GX9", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX9) },
 	{ "DMC-FZ8", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ8) },
 	{ "DMC-FZ18", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ18) },
 	{ "DMC-FZ28", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ28) },
@@ -247,6 +289,7 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
 	{ "DMC-G5", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G5) },
 	{ "DMC-G10", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G10) },
 	{ "DMC-G80", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G80) },
+	{ "DC-G9", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G9) },
 	{ "DMC-GH1", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GH1) },
 	{ "DMC-GH2", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GH2) },
 	{ "DMC-GH3", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GH3) },
@@ -263,6 +306,8 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
 	{ "DMC-L1", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_L1) },
 	{ "DMC-L10", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_L10) },
 	{ "DMC-TZ100", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ100) },
+	{ "DMC-TZ110", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ110) },
+	{ "DC-TZ202", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ202) },
 	{ "DMC-TZ70", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ70) },
 	{ "DMC-TZ80", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ80) },
 	{ "DMC-ZS100", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS100) },
@@ -270,6 +315,8 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
 	{ "DIGILUX 2", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DIGILUX2) },
 	{ "D-LUX 3", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_3) },
 	{ "V-LUX 1", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_VLUX_1) },
+	{ "D-LUX (Typ 109)", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_TYP109) },
+	{ "V-LUX 4", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_VLUX_4) },
 
 	{ 0, 0 }
 };
@@ -313,7 +360,7 @@ IfdDir::Ref  Rw2File::_locateMainIfd()
     if(size == 0) {
         return OR_ERROR_NOT_FOUND;
     }
-    Trace(DEBUG1) << "Jpeg offset: " << offset << "\n";
+    LOGDBG1("Jpeg offset: %u\n", offset);
 
     uint32_t x = 0;
     uint32_t y = 0;
@@ -321,8 +368,7 @@ IfdDir::Ref  Rw2File::_locateMainIfd()
     IO::Stream::Ptr s(new IO::StreamClone(m_io, offset));
     std::unique_ptr<JfifContainer> jfif(new JfifContainer(s, 0));
     if (jfif->getDimensions(x,y)) {
-        Trace(DEBUG1) << "JPEG dimensions x=" << x
-                      << " y=" << y << "\n";
+        LOGDBG1("JPEG dimensions x=%u y=%u\n", x, y);
     }
     if(_type != OR_DATA_TYPE_NONE) {
         uint32_t dim = std::max(x, y);
@@ -338,7 +384,7 @@ uint32_t Rw2File::_getJpegThumbnailOffset(const IfdDir::Ref & dir, uint32_t & le
     IfdEntry::Ref e = dir->getEntry(IFD::RW2_TAG_JPEG_FROM_RAW);
 	if(!e) {
 	    len = 0;
-		Trace(DEBUG1) << "JpegFromRaw not found\n";
+		LOGDBG1("JpegFromRaw not found\n");
 		return 0;
 	}
     uint32_t offset = e->offset();
@@ -352,46 +398,48 @@ uint32_t Rw2File::_getJpegThumbnailOffset(const IfdDir::Ref & dir, uint32_t & le
 	::or_error ret = OR_ERROR_NONE;
 	const IfdDir::Ref & _cfaIfd = cfaIfd();
 	if(!_cfaIfd) {
-		Trace(DEBUG1) << "cfa IFD not found\n";
+		LOGDBG1("cfa IFD not found\n");
 		return OR_ERROR_NOT_FOUND;
 	}
 
-	Trace(DEBUG1) << "_getRawData()\n";
+	LOGDBG1("_getRawData()\n");
 	uint32_t offset = 0;
 	uint32_t byte_length = 0;
-	bool got_it;
 	// RW2 file
-	got_it = _cfaIfd->getIntegerValue(IFD::RW2_TAG_STRIP_OFFSETS, offset);
-	if(got_it) {
+	auto result = _cfaIfd->getIntegerValue(IFD::RW2_TAG_STRIP_OFFSETS);
+	if(result) {
+		offset = result.value();
         byte_length = m_container->file()->filesize() - offset;
     }
     else {
         // RAW file alternative.
-        got_it = _cfaIfd->getIntegerValue(IFD::EXIF_TAG_STRIP_OFFSETS, offset);
-        if(!got_it) {
-            Trace(DEBUG1) << "offset not found\n";
+		result = _cfaIfd->getIntegerValue(IFD::EXIF_TAG_STRIP_OFFSETS);
+        if(result.empty()) {
+            LOGDBG1("offset not found\n");
             return OR_ERROR_NOT_FOUND;
         }
-        got_it = _cfaIfd->getIntegerValue(IFD::EXIF_TAG_STRIP_BYTE_COUNTS, byte_length);
-        if(!got_it) {
-            Trace(DEBUG1) << "byte len not found\n";
+		offset = result.value();
+        result = _cfaIfd->getIntegerValue(IFD::EXIF_TAG_STRIP_BYTE_COUNTS);
+        if(result.empty()) {
+            LOGDBG1("byte len not found\n");
             return OR_ERROR_NOT_FOUND;
         }
+		byte_length = result.value();
     }
 
-	uint32_t x, y;
-	x = 0;
-	y = 0;
-	got_it = _cfaIfd->getIntegerValue(IFD::RW2_TAG_SENSOR_WIDTH, x);
-	if(!got_it) {
-		Trace(DEBUG1) << "X not found\n";
+	result = _cfaIfd->getIntegerValue(IFD::RW2_TAG_SENSOR_WIDTH);
+	if(result.empty()) {
+		LOGDBG1("X not found\n");
 		return OR_ERROR_NOT_FOUND;
 	}
-	got_it = _cfaIfd->getIntegerValue(IFD::RW2_TAG_SENSOR_HEIGHT, y);
-	if(!got_it) {
-		Trace(DEBUG1) << "Y not found\n";
+	uint32_t x = result.value();
+
+	result = _cfaIfd->getIntegerValue(IFD::RW2_TAG_SENSOR_HEIGHT);
+	if(result.empty()) {
+		LOGDBG1("Y not found\n");
 		return OR_ERROR_NOT_FOUND;
 	}
+	uint32_t y = result.value();
 
 	// this is were things are complicated. The real size of the raw data
 	// is whatever is read (if compressed)
@@ -404,8 +452,8 @@ uint32_t Rw2File::_getJpegThumbnailOffset(const IfdDir::Ref & dir, uint32_t & le
 		data.setCompression(PANA_RAW_COMPRESSION);
 	}
 	else if (real_size < byte_length) {
-		Trace(WARNING) << "Size mismatch for data: expected " << byte_length
-			<< " got " << real_size << " ignoring.\n";
+		LOGWARN("Size mismatch for data: expected %u got %lu ignoring.\n",
+				byte_length, real_size);
 		return OR_ERROR_NOT_FOUND;
 	}
 	else {
@@ -419,9 +467,9 @@ uint32_t Rw2File::_getJpegThumbnailOffset(const IfdDir::Ref & dir, uint32_t & le
 	//
 	data.setDimensions(x, y);
 
-	Trace(DEBUG1) << "In size is " << data.width()
-				  << "x" << data.height() << "\n";
+	LOGDBG1("In size is %ux%u\n", data.width(), data.height());
 	// get the sensor info
+	// XXX what if it is not found?
 	IfdEntry::Ref e = _cfaIfd->getEntry(IFD::RW2_TAG_SENSOR_LEFTBORDER);
 	x = e->getIntegerArrayItem(0);
 	e = _cfaIfd->getEntry(IFD::RW2_TAG_SENSOR_TOPBORDER);
